@@ -16,7 +16,7 @@ You can download the Quake III Arena demo ( copyright id software )
 at the following location:
 ftp://ftp.idsoftware.com/idstuff/quake3/win32/q3ademo.exe
 
-Copyright 2006-2009 Burningwater, Thomas Alten
+This file is copyright 2006-2010 Burningwater, Thomas Alten
 */
 
 #include "q3factory.h"
@@ -1771,6 +1771,7 @@ void CQuake3EventHandler::useItem( Q3Player * player)
 
 	node->setMaterialFlag(EMF_LIGHTING, false);
 	node->setMaterialTexture(0, Game->Device->getVideoDriver()->getTexture("fireball.bmp"));
+	node->setMaterialFlag(video::EMF_ZWRITE_ENABLE, false);
 	node->setMaterialType(EMT_TRANSPARENT_ADD_COLOR);
 
 	f32 length = (f32)(end - start).getLength();
@@ -1884,6 +1885,7 @@ void CQuake3EventHandler::createParticleImpacts( u32 now )
 			anim->drop();
 
 			pas->setMaterialFlag(video::EMF_LIGHTING, false);
+			pas->setMaterialFlag(video::EMF_ZWRITE_ENABLE, false);
 			pas->setMaterialType(video::EMT_TRANSPARENT_VERTEX_ALPHA );
 			pas->setMaterialTexture(0, Game->Device->getVideoDriver()->getTexture( smoke[g].texture ));
 		}
@@ -1931,7 +1933,7 @@ void CQuake3EventHandler::Render()
 		driver->beginScene(true, true, SColor(0,0,0,0));
 		driver->getOverrideMaterial().Material.ColorMask = ECP_NONE;
 		driver->getOverrideMaterial().EnableFlags  = EMF_COLOR_MASK;
-        driver->getOverrideMaterial().EnablePasses = ESNRP_SKY_BOX + 
+        driver->getOverrideMaterial().EnablePasses = ESNRP_SKY_BOX +
                                                      ESNRP_SOLID +
                                                      ESNRP_TRANSPARENT +
                                                      ESNRP_TRANSPARENT_EFFECT +
@@ -1957,7 +1959,7 @@ void CQuake3EventHandler::Render()
 
 		driver->getOverrideMaterial().Material.ColorMask = ECP_RED;
 		driver->getOverrideMaterial().EnableFlags  = EMF_COLOR_MASK;
-		driver->getOverrideMaterial().EnablePasses = 
+		driver->getOverrideMaterial().EnablePasses =
 				ESNRP_SKY_BOX|ESNRP_SOLID|ESNRP_TRANSPARENT|
 				ESNRP_TRANSPARENT_EFFECT|ESNRP_SHADOW;
 
@@ -1973,7 +1975,7 @@ void CQuake3EventHandler::Render()
 
 		driver->getOverrideMaterial().Material.ColorMask = ECP_GREEN + ECP_BLUE;
 		driver->getOverrideMaterial().EnableFlags  = EMF_COLOR_MASK;
-		driver->getOverrideMaterial().EnablePasses = 
+		driver->getOverrideMaterial().EnablePasses =
 				ESNRP_SKY_BOX|ESNRP_SOLID|ESNRP_TRANSPARENT|
 				ESNRP_TRANSPARENT_EFFECT|ESNRP_SHADOW;
 
