@@ -1,4 +1,4 @@
-// Copyright (C) 2002-2010 Nikolaus Gebhardt
+// Copyright (C) 2002-2011 Nikolaus Gebhardt
 // This file is part of the "Irrlicht Engine".
 // For conditions of distribution and use, see copyright notice in irrlicht.h
 
@@ -55,17 +55,7 @@ CGUIEditBox::CGUIEditBox(const wchar_t* text, bool border,
 	setTabStop(true);
 	setTabOrder(-1);
 
-	IGUISkin *skin = 0;
-	if (Environment)
-		skin = Environment->getSkin();
-	if (Border && skin)
-	{
-		FrameRect.UpperLeftCorner.X += skin->getSize(EGDS_TEXT_DISTANCE_X)+1;
-		FrameRect.UpperLeftCorner.Y += skin->getSize(EGDS_TEXT_DISTANCE_Y)+1;
-		FrameRect.LowerRightCorner.X -= skin->getSize(EGDS_TEXT_DISTANCE_X)+1;
-		FrameRect.LowerRightCorner.Y -= skin->getSize(EGDS_TEXT_DISTANCE_Y)+1;
-	}
-
+	calculateFrameRect();
 	breakText();
 
 	calculateScrollPos();
@@ -137,7 +127,9 @@ void CGUIEditBox::updateAbsolutePosition()
 	IGUIElement::updateAbsolutePosition();
 	if ( oldAbsoluteRect != AbsoluteRect )
 	{
+		calculateFrameRect();
         breakText();
+        calculateScrollPos();
 	}
 }
 
@@ -496,7 +488,7 @@ bool CGUIEditBox::processKey(const SEvent& event)
 			{
 				s32 cp = CursorPos - BrokenTextPositions[lineNo];
 				if ((s32)BrokenText[lineNo-1].size() < cp)
-					CursorPos = BrokenTextPositions[lineNo-1] + (s32)BrokenText[lineNo-1].size()-1;
+					CursorPos = BrokenTextPositions[lineNo-1] + core::max_((u32)1, BrokenText[lineNo-1].size())-1;
 				else
 					CursorPos = BrokenTextPositions[lineNo-1] + cp;
 			}
@@ -527,7 +519,7 @@ bool CGUIEditBox::processKey(const SEvent& event)
 			{
 				s32 cp = CursorPos - BrokenTextPositions[lineNo];
 				if ((s32)BrokenText[lineNo+1].size() < cp)
-					CursorPos = BrokenTextPositions[lineNo+1] + BrokenText[lineNo+1].size()-1;
+					CursorPos = BrokenTextPositions[lineNo+1] + core::max_((u32)1, BrokenText[lineNo+1].size())-1;
 				else
 					CursorPos = BrokenTextPositions[lineNo+1] + cp;
 			}
@@ -691,20 +683,16 @@ void CGUIEditBox::draw()
 	if (!skin)
 		return;
 
-	FrameRect = AbsoluteRect;
-
 	// draw the border
 
 	if (Border)
 	{
 		skin->draw3DSunkenPane(this, skin->getColor(EGDC_WINDOW),
-			false, true, FrameRect, &AbsoluteClippingRect);
+			false, true, AbsoluteRect, &AbsoluteClippingRect);
 
-		FrameRect.UpperLeftCorner.X += skin->getSize(EGDS_TEXT_DISTANCE_X)+1;
-		FrameRect.UpperLeftCorner.Y += skin->getSize(EGDS_TEXT_DISTANCE_Y)+1;
-		FrameRect.LowerRightCorner.X -= skin->getSize(EGDS_TEXT_DISTANCE_X)+1;
-		FrameRect.LowerRightCorner.Y -= skin->getSize(EGDS_TEXT_DISTANCE_Y)+1;
+		calculateFrameRect();
 	}
+
 	core::rect<s32> localClipRect = FrameRect;
 	localClipRect.clipAgainst(AbsoluteClippingRect);
 
@@ -846,25 +834,27 @@ void CGUIEditBox::draw()
 		}
 
 		// draw cursor
-
-		if (WordWrap || MultiLine)
+		if ( IsEnabled )
 		{
-			cursorLine = getLineFromPos(CursorPos);
-			txtLine = &BrokenText[cursorLine];
-			startPos = BrokenTextPositions[cursorLine];
-		}
-		s = txtLine->subString(0,CursorPos-startPos);
-		charcursorpos = font->getDimension(s.c_str()).Width +
-			font->getKerningWidth(L"_", CursorPos-startPos > 0 ? &((*txtLine)[CursorPos-startPos-1]) : 0);
+			if (WordWrap || MultiLine)
+			{
+				cursorLine = getLineFromPos(CursorPos);
+				txtLine = &BrokenText[cursorLine];
+				startPos = BrokenTextPositions[cursorLine];
+			}
+			s = txtLine->subString(0,CursorPos-startPos);
+			charcursorpos = font->getDimension(s.c_str()).Width +
+				font->getKerningWidth(L"_", CursorPos-startPos > 0 ? &((*txtLine)[CursorPos-startPos-1]) : 0);
 
-		if (focus && (os::Timer::getTime() - BlinkStartTime) % 700 < 350)
-		{
-			setTextRect(cursorLine);
-			CurrentTextRect.UpperLeftCorner.X += charcursorpos;
+			if (focus && (os::Timer::getTime() - BlinkStartTime) % 700 < 350)
+			{
+				setTextRect(cursorLine);
+				CurrentTextRect.UpperLeftCorner.X += charcursorpos;
 
-			font->draw(L"_", CurrentTextRect,
-				OverrideColorEnabled ? OverrideColor : skin->getColor(EGDC_BUTTON_TEXT),
-				false, true, &localClipRect);
+				font->draw(L"_", CurrentTextRect,
+					OverrideColorEnabled ? OverrideColor : skin->getColor(EGDC_BUTTON_TEXT),
+					false, true, &localClipRect);
+			}
 		}
 	}
 
@@ -1042,7 +1032,7 @@ s32 CGUIEditBox::getCursorPos(s32 x, s32 y)
 	if (x < CurrentTextRect.UpperLeftCorner.X)
 		x = CurrentTextRect.UpperLeftCorner.X;
 
-	s32 idx = font->getCharacterFromPos(Text.c_str(), x - CurrentTextRect.UpperLeftCorner.X);
+	s32 idx = txtLine ? font->getCharacterFromPos(txtLine->c_str(), x - CurrentTextRect.UpperLeftCorner.X) : -1;
 
 	// click was on or left of the line
 	if (idx != -1)
@@ -1093,8 +1083,13 @@ void CGUIEditBox::breakText()
 			c = ' ';
 			if (Text[i+1] == L'\n') // Windows breaks
 			{
+				// TODO: I (Michael) think that we shouldn't change the text given by the user for whatever reason.
+				// Instead rework the cursor positioning to be able to handle this (but not in stable release 
+				// branch as users might already expect this behaviour).
 				Text.erase(i+1);
 				--size;
+				if ( CursorPos > i )
+					--CursorPos;
 			}
 		}
 		else if (c == L'\n') // Unix breaks
@@ -1109,33 +1104,30 @@ void CGUIEditBox::breakText()
 
 		if (c == L' ' || c == 0 || i == (size-1))
 		{
-			if (word.size())
+			// here comes the next whitespace, look if
+			// we can break the last word to the next line.
+			s32 whitelgth = font->getDimension(whitespace.c_str()).Width;
+			s32 worldlgth = font->getDimension(word.c_str()).Width;
+
+			if (WordWrap && length + worldlgth + whitelgth > elWidth && line.size() > 0)
 			{
-				// here comes the next whitespace, look if
-				// we can break the last word to the next line.
-				s32 whitelgth = font->getDimension(whitespace.c_str()).Width;
-				s32 worldlgth = font->getDimension(word.c_str()).Width;
-
-				if (WordWrap && length + worldlgth + whitelgth > elWidth)
-				{
-					// break to next line
-					length = worldlgth;
-					BrokenText.push_back(line);
-					BrokenTextPositions.push_back(lastLineStart);
-					lastLineStart = i - (s32)word.size();
-					line = word;
-				}
-				else
-				{
-					// add word to line
-					line += whitespace;
-					line += word;
-					length += whitelgth + worldlgth;
-				}
-
-				word = L"";
-				whitespace = L"";
+				// break to next line
+				length = worldlgth;
+				BrokenText.push_back(line);
+				BrokenTextPositions.push_back(lastLineStart);
+				lastLineStart = i - (s32)word.size();
+				line = word;
 			}
+			else
+			{
+				// add word to line
+				line += whitespace;
+				line += word;
+				length += whitelgth + worldlgth;
+			}
+
+			word = L"";
+			whitespace = L"";
 
 			whitespace += c;
 
@@ -1166,7 +1158,10 @@ void CGUIEditBox::breakText()
 	BrokenTextPositions.push_back(lastLineStart);
 }
 
-
+// TODO: that function does interpret VAlign according to line-index (indexed line is placed on top-center-bottom)
+// but HAlign according to line-width (pixels) and not by row.
+// Intuitively I suppose HAlign handling is better as VScrollPos should handle the line-scrolling.
+// But please no one change this without also rewriting (and this time fucking testing!!!) autoscrolling (I noticed this when fixing the old autoscrolling).
 void CGUIEditBox::setTextRect(s32 line)
 {
 	core::dimension2du d;
@@ -1299,55 +1294,138 @@ void CGUIEditBox::inputChar(wchar_t c)
 	calculateScrollPos();
 }
 
-
+// calculate autoscroll
 void CGUIEditBox::calculateScrollPos()
 {
 	if (!AutoScroll)
 		return;
 
-	// calculate horizontal scroll position
+	IGUISkin* skin = Environment->getSkin();
+	if (!skin)
+		return;
+	IGUIFont* font = OverrideFont ? OverrideFont : skin->getFont();
+	if (!font)
+		return;
+
 	s32 cursLine = getLineFromPos(CursorPos);
-	setTextRect(cursLine);
+	bool hasBrokenText = MultiLine || WordWrap;
 
-	// don't do horizontal scrolling when wordwrap is enabled.
-	if (!WordWrap)
+	// Check horizonal scrolling
+	// NOTE: Calculations different to vertical scrolling because setTextRect interprets VAlign relative to line but HAlign not relative to row
 	{
-		// get cursor position
-		IGUISkin* skin = Environment->getSkin();
-		if (!skin)
-			return;
-		IGUIFont* font = OverrideFont ? OverrideFont : skin->getFont();
-		if (!font)
-			return;
+		setTextRect(cursLine);
 
-		core::stringw *txtLine = MultiLine ? &BrokenText[cursLine] : &Text;
-		s32 cPos = MultiLine ? CursorPos - BrokenTextPositions[cursLine] : CursorPos;
+		// get cursor area
+		irr::u32 cursorWidth = font->getDimension(L"_").Width;
+		core::stringw *txtLine = hasBrokenText ? &BrokenText[cursLine] : &Text;
+		s32 cPos = hasBrokenText ? CursorPos - BrokenTextPositions[cursLine] : CursorPos;	// column
+		s32 cStart = font->getDimension(txtLine->subString(0, cPos).c_str()).Width;		// pixels from text-start
+		s32 cEnd = cStart + cursorWidth;
+		s32 txtWidth = font->getDimension(txtLine->c_str()).Width;
 
-		s32 cStart = CurrentTextRect.UpperLeftCorner.X + HScrollPos +
-			font->getDimension(txtLine->subString(0, cPos).c_str()).Width;
+		if ( txtWidth < FrameRect.getWidth() )
+		{
+			// TODO: Needs a clean left and right gap removal depending on HAlign, similar to vertical scrolling tests for top/bottom.
+			// This check just fixes the case where it was most noticable (text smaller than clipping area).
 
-		s32 cEnd = cStart + font->getDimension(L"_ ").Width;
-
-		if (FrameRect.LowerRightCorner.X < cEnd)
-			HScrollPos = cEnd - FrameRect.LowerRightCorner.X;
-		else if (FrameRect.UpperLeftCorner.X > cStart)
-			HScrollPos = cStart - FrameRect.UpperLeftCorner.X;
-		else
 			HScrollPos = 0;
+			setTextRect(cursLine);
+		}
 
-		// todo: adjust scrollbar
+		if ( CurrentTextRect.UpperLeftCorner.X+cStart < FrameRect.UpperLeftCorner.X )
+		{
+			// cursor to the left of the clipping area
+			HScrollPos -= FrameRect.UpperLeftCorner.X-(CurrentTextRect.UpperLeftCorner.X+cStart);
+			setTextRect(cursLine);
+
+			// TODO: should show more characters to the left when we're scrolling left
+			//	and the cursor reaches the border.
+		}
+		else if ( CurrentTextRect.UpperLeftCorner.X+cEnd > FrameRect.LowerRightCorner.X)
+		{
+			// cursor to the right of the clipping area
+			HScrollPos += (CurrentTextRect.UpperLeftCorner.X+cEnd)-FrameRect.LowerRightCorner.X;
+			setTextRect(cursLine);
+		}
 	}
 
-	// vertical scroll position
-	if (FrameRect.LowerRightCorner.Y < CurrentTextRect.LowerRightCorner.Y + VScrollPos)
-		VScrollPos = CurrentTextRect.LowerRightCorner.Y - FrameRect.LowerRightCorner.Y + VScrollPos;
+	// calculate vertical scrolling
+	if (hasBrokenText)
+	{
+		irr::u32 lineHeight = font->getDimension(L"A").Height + font->getKerningHeight();
+		// only up to 1 line fits?
+		if ( lineHeight >= (irr::u32)FrameRect.getHeight() )
+		{
+			VScrollPos = 0;
+			setTextRect(cursLine);
+			s32 unscrolledPos = CurrentTextRect.UpperLeftCorner.Y;
+			s32 pivot = FrameRect.UpperLeftCorner.Y;
+			switch (VAlign)
+			{
+				case EGUIA_CENTER:
+					pivot += FrameRect.getHeight()/2;
+					unscrolledPos += lineHeight/2;
+					break;
+				case EGUIA_LOWERRIGHT:
+					pivot += FrameRect.getHeight();
+					unscrolledPos += lineHeight;
+					break;
+				default:
+					break;
+			}
+			VScrollPos = unscrolledPos-pivot;
+			setTextRect(cursLine);
+		}
+		else
+		{
+			// First 2 checks are necessary when people delete lines
+			setTextRect(0);
+			if ( CurrentTextRect.UpperLeftCorner.Y > FrameRect.UpperLeftCorner.Y && VAlign != EGUIA_LOWERRIGHT)
+			{
+				// first line is leaving a gap on top
+				VScrollPos = 0;
+			}
+			else if (VAlign != EGUIA_UPPERLEFT)
+			{
+				u32 lastLine = BrokenTextPositions.empty() ? 0 : BrokenTextPositions.size()-1;
+				setTextRect(lastLine);
+				if ( CurrentTextRect.LowerRightCorner.Y < FrameRect.LowerRightCorner.Y)
+				{
+					// last line is leaving a gap on bottom
+					VScrollPos -= FrameRect.LowerRightCorner.Y-CurrentTextRect.LowerRightCorner.Y;
+				}
+			}
 
-	else if (FrameRect.UpperLeftCorner.Y > CurrentTextRect.UpperLeftCorner.Y + VScrollPos)
-		VScrollPos = CurrentTextRect.UpperLeftCorner.Y - FrameRect.UpperLeftCorner.Y + VScrollPos;
-	else
-		VScrollPos = 0;
+			setTextRect(cursLine);
+			if ( CurrentTextRect.UpperLeftCorner.Y < FrameRect.UpperLeftCorner.Y )
+			{
+				// text above valid area
+				VScrollPos -= FrameRect.UpperLeftCorner.Y-CurrentTextRect.UpperLeftCorner.Y;
+				setTextRect(cursLine);
+			}
+			else if ( CurrentTextRect.LowerRightCorner.Y > FrameRect.LowerRightCorner.Y)
+			{
+				// text below valid area
+				VScrollPos += CurrentTextRect.LowerRightCorner.Y-FrameRect.LowerRightCorner.Y;
+				setTextRect(cursLine);
+			}
+		}
+	}
+}
 
-	// todo: adjust scrollbar
+void CGUIEditBox::calculateFrameRect()
+{
+	FrameRect = AbsoluteRect;
+	IGUISkin *skin = 0;
+	if (Environment)
+		skin = Environment->getSkin();
+	if (Border && skin)
+	{
+		FrameRect.UpperLeftCorner.X += skin->getSize(EGDS_TEXT_DISTANCE_X)+1;
+		FrameRect.UpperLeftCorner.Y += skin->getSize(EGDS_TEXT_DISTANCE_Y)+1;
+		FrameRect.LowerRightCorner.X -= skin->getSize(EGDS_TEXT_DISTANCE_X)+1;
+		FrameRect.LowerRightCorner.Y -= skin->getSize(EGDS_TEXT_DISTANCE_Y)+1;
+	}
 }
 
 //! set text markers
