@@ -1,4 +1,4 @@
-// Copyright (C) 2002-2009 Nikolaus Gebhardt
+// Copyright (C) 2002-2010 Nikolaus Gebhardt
 // This file is part of the "Irrlicht Engine".
 // For conditions of distribution and use, see copyright notice in irrlicht.h
 
@@ -170,9 +170,9 @@ CIrrDeviceLinux::~CIrrDeviceLinux()
 #endif // #ifdef _IRR_COMPILE_WITH_X11_
 
 #if defined(_IRR_COMPILE_WITH_JOYSTICK_EVENTS_)
-	for(u32 joystick = 0; joystick < ActiveJoysticks.size(); ++joystick)
+	for (u32 joystick = 0; joystick < ActiveJoysticks.size(); ++joystick)
 	{
-		if(ActiveJoysticks[joystick].fd >= 0)
+		if (ActiveJoysticks[joystick].fd >= 0)
 		{
 			close(ActiveJoysticks[joystick].fd);
 		}
@@ -244,13 +244,16 @@ bool CIrrDeviceLinux::switchToFullscreen(bool reset)
 			else if (bestMode!=-1 &&
 					modes[i]->hdisplay >= Width &&
 					modes[i]->vdisplay >= Height &&
-					modes[i]->hdisplay < modes[bestMode]->hdisplay &&
-					modes[i]->vdisplay < modes[bestMode]->vdisplay)
+					modes[i]->hdisplay <= modes[bestMode]->hdisplay &&
+					modes[i]->vdisplay <= modes[bestMode]->vdisplay)
 				bestMode = i;
 		}
 		if (bestMode != -1)
 		{
-			os::Printer::log("Starting fullscreen mode...", ELL_INFORMATION);
+			os::Printer::log("Starting vidmode fullscreen mode...", ELL_INFORMATION);
+			os::Printer::log("hdisplay: ", core::stringc(modes[bestMode]->hdisplay).c_str(), ELL_INFORMATION);
+			os::Printer::log("vdisplay: ", core::stringc(modes[bestMode]->vdisplay).c_str(), ELL_INFORMATION);
+
 			XF86VidModeSwitchToMode(display, screennr, modes[bestMode]);
 			XF86VidModeSetViewPort(display, screennr, 0, 0);
 			UseXVidMode=true;
@@ -278,12 +281,16 @@ bool CIrrDeviceLinux::switchToFullscreen(bool reset)
 			else if (bestMode!=-1 &&
 					(u32)modes[i].width >= Width &&
 					(u32)modes[i].height >= Height &&
-					modes[i].width < modes[bestMode].width &&
-					modes[i].height < modes[bestMode].height)
+					modes[i].width <= modes[bestMode].width &&
+					modes[i].height <= modes[bestMode].height)
 				bestMode = i;
 		}
 		if (bestMode != -1)
 		{
+			os::Printer::log("Starting randr fullscreen mode...", ELL_INFORMATION);
+			os::Printer::log("width: ", core::stringc(modes[bestMode].width).c_str(), ELL_INFORMATION);
+			os::Printer::log("height: ", core::stringc(modes[bestMode].height).c_str(), ELL_INFORMATION);
+
 			XRRSetScreenConfig(display,config,DefaultRootWindow(display),bestMode,oldRandrRotation,CurrentTime);
 			UseXRandR=true;
 		}
@@ -992,21 +999,42 @@ bool CIrrDeviceLinux::run()
 					char buf[8]={0};
 					XLookupString(&event.xkey, buf, sizeof(buf), &mp.X11Key, NULL);
 
-					const s32 idx = KeyMap.binary_search(mp);
-
-					if (idx != -1)
-						irrevent.KeyInput.Key = (EKEY_CODE)KeyMap[idx].Win32Key;
-					else
-					{
-						irrevent.KeyInput.Key = (EKEY_CODE)0;
-						os::Printer::log("Could not find win32 key for x11 key.", core::stringc((int)mp.X11Key).c_str(), ELL_WARNING);
-					}
 					irrevent.EventType = irr::EET_KEY_INPUT_EVENT;
 					irrevent.KeyInput.PressedDown = (event.type == KeyPress);
 //					mbtowc(&irrevent.KeyInput.Char, buf, sizeof(buf));
 					irrevent.KeyInput.Char = ((wchar_t*)(buf))[0];
 					irrevent.KeyInput.Control = (event.xkey.state & ControlMask) != 0;
 					irrevent.KeyInput.Shift = (event.xkey.state & ShiftMask) != 0;
+
+					event.xkey.state = 0; // ignore shift-ctrl states for figuring out the key
+					XLookupString(&event.xkey, buf, sizeof(buf), &mp.X11Key, NULL);
+                    const s32 idx = KeyMap.binary_search(mp);
+					if (idx != -1)
+					{
+						irrevent.KeyInput.Key = (EKEY_CODE)KeyMap[idx].Win32Key;
+					}
+					else
+					{
+						irrevent.KeyInput.Key = (EKEY_CODE)0;
+                    }
+                    if (irrevent.KeyInput.Key == 0)
+                    {
+                        // 1:1 mapping to windows-keys would require testing for keyboard type (us, ger, ...)
+                        // So unless we do that we will have some unknown keys here.
+                        if (idx == -1)
+                        {
+                            os::Printer::log("Could not find EKEY_CODE, using orig. X11 keycode instead", core::stringc(event.xkey.keycode).c_str(), ELL_INFORMATION);
+                        }
+                        else
+                        {
+                            os::Printer::log("EKEY_CODE is 0, using orig. X11 keycode instead", core::stringc(event.xkey.keycode).c_str(), ELL_INFORMATION);
+                        }
+                        // Any value is better than none, that allows at least using the keys.
+                        // Worst case is that some keys will be identical, still better than _all_
+                        // unknown keys being identical.
+                        irrevent.KeyInput.Key = (EKEY_CODE)event.xkey.keycode;
+                    }
+
 					postEventFromUser(irrevent);
 				}
 				break;
@@ -1083,7 +1111,7 @@ bool CIrrDeviceLinux::run()
 	}
 #endif //_IRR_COMPILE_WITH_X11_
 
-	if(!Close)
+	if (!Close)
 		pollJoysticks();
 
 	return !Close;
@@ -1125,10 +1153,13 @@ void CIrrDeviceLinux::setWindowCaption(const wchar_t* text)
 		return;
 
 	XTextProperty txt;
-	XwcTextListToTextProperty(display, const_cast<wchar_t**>(&text), 1, XStdICCTextStyle, &txt);
-	XSetWMName(display, window, &txt);
-	XSetWMIconName(display, window, &txt);
-	XFree(txt.value);
+	if (Success==XwcTextListToTextProperty(display, const_cast<wchar_t**>(&text),
+				1, XStdICCTextStyle, &txt))
+	{
+		XSetWMName(display, window, &txt);
+		XSetWMIconName(display, window, &txt);
+		XFree(txt.value);
+	}
 #endif
 }
 
@@ -1232,7 +1263,7 @@ video::ECOLOR_FORMAT CIrrDeviceLinux::getColorFormat() const
 void CIrrDeviceLinux::setResizable(bool resize)
 {
 #ifdef _IRR_COMPILE_WITH_X11_
-	if (CreationParams.DriverType == video::EDT_NULL)
+	if (CreationParams.DriverType == video::EDT_NULL || CreationParams.Fullscreen )
 		return;
 
 	XUnmapWindow(display, window);
@@ -1372,6 +1403,7 @@ void CIrrDeviceLinux::createKeyMap()
 	KeyMap.reallocate(84);
 	KeyMap.push_back(SKeyMap(XK_BackSpace, KEY_BACK));
 	KeyMap.push_back(SKeyMap(XK_Tab, KEY_TAB));
+	KeyMap.push_back(SKeyMap(XK_ISO_Left_Tab, KEY_TAB));
 	KeyMap.push_back(SKeyMap(XK_Linefeed, 0)); // ???
 	KeyMap.push_back(SKeyMap(XK_Clear, KEY_CLEAR));
 	KeyMap.push_back(SKeyMap(XK_Return, KEY_RETURN));
@@ -1459,11 +1491,11 @@ void CIrrDeviceLinux::createKeyMap()
 	KeyMap.push_back(SKeyMap(XK_exclam, 0)); //?
 	KeyMap.push_back(SKeyMap(XK_quotedbl, 0)); //?
 	KeyMap.push_back(SKeyMap(XK_section, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_numbersign, 0)); //?
+	KeyMap.push_back(SKeyMap(XK_numbersign, KEY_OEM_2));
 	KeyMap.push_back(SKeyMap(XK_dollar, 0)); //?
 	KeyMap.push_back(SKeyMap(XK_percent, 0)); //?
 	KeyMap.push_back(SKeyMap(XK_ampersand, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_apostrophe, 0)); //?
+	KeyMap.push_back(SKeyMap(XK_apostrophe, KEY_OEM_7));
 	KeyMap.push_back(SKeyMap(XK_parenleft, 0)); //?
 	KeyMap.push_back(SKeyMap(XK_parenright, 0)); //?
 	KeyMap.push_back(SKeyMap(XK_asterisk, 0)); //?
@@ -1471,7 +1503,7 @@ void CIrrDeviceLinux::createKeyMap()
 	KeyMap.push_back(SKeyMap(XK_comma, KEY_COMMA)); //?
 	KeyMap.push_back(SKeyMap(XK_minus, KEY_MINUS)); //?
 	KeyMap.push_back(SKeyMap(XK_period, KEY_PERIOD)); //?
-	KeyMap.push_back(SKeyMap(XK_slash, 0)); //?
+	KeyMap.push_back(SKeyMap(XK_slash, KEY_OEM_2)); //?
 	KeyMap.push_back(SKeyMap(XK_0, KEY_KEY_0));
 	KeyMap.push_back(SKeyMap(XK_1, KEY_KEY_1));
 	KeyMap.push_back(SKeyMap(XK_2, KEY_KEY_2));
@@ -1483,12 +1515,12 @@ void CIrrDeviceLinux::createKeyMap()
 	KeyMap.push_back(SKeyMap(XK_8, KEY_KEY_8));
 	KeyMap.push_back(SKeyMap(XK_9, KEY_KEY_9));
 	KeyMap.push_back(SKeyMap(XK_colon, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_semicolon, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_less, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_equal, 0)); //?
+	KeyMap.push_back(SKeyMap(XK_semicolon, KEY_OEM_1));
+	KeyMap.push_back(SKeyMap(XK_less, KEY_OEM_102));
+	KeyMap.push_back(SKeyMap(XK_equal, KEY_PLUS));
 	KeyMap.push_back(SKeyMap(XK_greater, 0)); //?
 	KeyMap.push_back(SKeyMap(XK_question, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_at, 0)); //?
+	KeyMap.push_back(SKeyMap(XK_at, KEY_KEY_2)); //?
 	KeyMap.push_back(SKeyMap(XK_mu, 0)); //?
 	KeyMap.push_back(SKeyMap(XK_EuroSign, 0)); //?
 	KeyMap.push_back(SKeyMap(XK_A, KEY_KEY_A));
@@ -1517,18 +1549,14 @@ void CIrrDeviceLinux::createKeyMap()
 	KeyMap.push_back(SKeyMap(XK_X, KEY_KEY_X));
 	KeyMap.push_back(SKeyMap(XK_Y, KEY_KEY_Y));
 	KeyMap.push_back(SKeyMap(XK_Z, KEY_KEY_Z));
-	KeyMap.push_back(SKeyMap(XK_Adiaeresis, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_Odiaeresis, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_Udiaeresis, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_bracketleft, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_backslash, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_bracketright, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_asciicircum, 0)); //?
+	KeyMap.push_back(SKeyMap(XK_bracketleft, KEY_OEM_4));
+	KeyMap.push_back(SKeyMap(XK_backslash, KEY_OEM_5));
+	KeyMap.push_back(SKeyMap(XK_bracketright, KEY_OEM_6));
+	KeyMap.push_back(SKeyMap(XK_asciicircum, KEY_OEM_5));
 	KeyMap.push_back(SKeyMap(XK_degree, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_underscore, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_grave, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_acute, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_quoteleft, 0)); //?
+	KeyMap.push_back(SKeyMap(XK_underscore, KEY_MINUS)); //?
+	KeyMap.push_back(SKeyMap(XK_grave, KEY_OEM_3));
+	KeyMap.push_back(SKeyMap(XK_acute, KEY_OEM_6));
 	KeyMap.push_back(SKeyMap(XK_a, KEY_KEY_A));
 	KeyMap.push_back(SKeyMap(XK_b, KEY_KEY_B));
 	KeyMap.push_back(SKeyMap(XK_c, KEY_KEY_C));
@@ -1555,10 +1583,12 @@ void CIrrDeviceLinux::createKeyMap()
 	KeyMap.push_back(SKeyMap(XK_x, KEY_KEY_X));
 	KeyMap.push_back(SKeyMap(XK_y, KEY_KEY_Y));
 	KeyMap.push_back(SKeyMap(XK_z, KEY_KEY_Z));
-	KeyMap.push_back(SKeyMap(XK_ssharp, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_adiaeresis, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_odiaeresis, 0)); //?
-	KeyMap.push_back(SKeyMap(XK_udiaeresis, 0)); //?
+	KeyMap.push_back(SKeyMap(XK_ssharp, KEY_OEM_4));
+	KeyMap.push_back(SKeyMap(XK_adiaeresis, KEY_OEM_7));
+	KeyMap.push_back(SKeyMap(XK_odiaeresis, KEY_OEM_3));
+	KeyMap.push_back(SKeyMap(XK_udiaeresis, KEY_OEM_1));
+	KeyMap.push_back(SKeyMap(XK_Super_L, KEY_LWIN));
+	KeyMap.push_back(SKeyMap(XK_Super_R, KEY_RWIN));
 
 	KeyMap.sort();
 #endif
@@ -1571,7 +1601,7 @@ bool CIrrDeviceLinux::activateJoysticks(core::array<SJoystickInfo> & joystickInf
 	joystickInfo.clear();
 
 	u32 joystick;
-	for(joystick = 0; joystick < 32; ++joystick)
+	for (joystick = 0; joystick < 32; ++joystick)
 	{
 		// The joystick device could be here...
 		core::stringc devName = "/dev/js";
@@ -1581,14 +1611,14 @@ bool CIrrDeviceLinux::activateJoysticks(core::array<SJoystickInfo> & joystickInf
 		JoystickInfo info;
 
 		info.fd = open(devName.c_str(), O_RDONLY);
-		if(-1 == info.fd)
+		if (-1 == info.fd)
 		{
 			// ...but Ubuntu and possibly other distros
 			// create the devices in /dev/input
 			devName = "/dev/input/js";
 			devName += joystick;
 			info.fd = open(devName.c_str(), O_RDONLY);
-			if(-1 == info.fd)
+			if (-1 == info.fd)
 			{
 				// and BSD here
 				devName = "/dev/joy";
@@ -1597,7 +1627,7 @@ bool CIrrDeviceLinux::activateJoysticks(core::array<SJoystickInfo> & joystickInf
 			}
 		}
 
-		if(-1 == info.fd)
+		if (-1 == info.fd)
 			continue;
 
 #ifdef __FREE_BSD_
@@ -1633,7 +1663,7 @@ bool CIrrDeviceLinux::activateJoysticks(core::array<SJoystickInfo> & joystickInf
 		joystickInfo.push_back(returnInfo);
 	}
 
-	for(joystick = 0; joystick < joystickInfo.size(); ++joystick)
+	for (joystick = 0; joystick < joystickInfo.size(); ++joystick)
 	{
 		char logString[256];
 		(void)sprintf(logString, "Found joystick %u, %u axes, %u buttons '%s'",
@@ -1652,24 +1682,23 @@ bool CIrrDeviceLinux::activateJoysticks(core::array<SJoystickInfo> & joystickInf
 void CIrrDeviceLinux::pollJoysticks()
 {
 #if defined (_IRR_COMPILE_WITH_JOYSTICK_EVENTS_)
-	if(0 == ActiveJoysticks.size())
+	if (0 == ActiveJoysticks.size())
 		return;
 
-	u32 j;
-	for(j= 0; j< ActiveJoysticks.size(); ++j)
+	for (u32 j= 0; j< ActiveJoysticks.size(); ++j)
 	{
 		JoystickInfo & info =  ActiveJoysticks[j];
 
 #ifdef __FREE_BSD_
 		struct joystick js;
-		if( read( info.fd, &js, JS_RETURN ) == JS_RETURN )
+		if (read(info.fd, &js, JS_RETURN) == JS_RETURN)
 		{
 			info.persistentData.JoystickEvent.ButtonStates = js.buttons; /* should be a two-bit field */
 			info.persistentData.JoystickEvent.Axis[0] = js.x; /* X axis */
 			info.persistentData.JoystickEvent.Axis[1] = js.y; /* Y axis */
 #else
 		struct js_event event;
-		while(sizeof(event) == read(info.fd, &event, sizeof(event)))
+		while (sizeof(event) == read(info.fd, &event, sizeof(event)))
 		{
 			switch(event.type & ~JS_EVENT_INIT)
 			{
@@ -1681,7 +1710,8 @@ void CIrrDeviceLinux::pollJoysticks()
 				break;
 
 			case JS_EVENT_AXIS:
-				info.persistentData.JoystickEvent.Axis[event.number] = event.value;
+				if (event.number < SEvent::SJoystickEvent::NUMBER_OF_AXES)
+					info.persistentData.JoystickEvent.Axis[event.number] = event.value;
 				break;
 
 			default:
