@@ -33,7 +33,6 @@ CMeshSceneNode::CMeshSceneNode(IMesh* mesh, ISceneNode* parent, ISceneManager* m
 }
 
 
-
 //! destructor
 CMeshSceneNode::~CMeshSceneNode()
 {
@@ -42,7 +41,6 @@ CMeshSceneNode::~CMeshSceneNode()
 }
 
 
-
 //! frame
 void CMeshSceneNode::OnRegisterSceneNode()
 {
@@ -110,7 +108,6 @@ void CMeshSceneNode::OnRegisterSceneNode()
 }
 
 
-
 //! renders the node.
 void CMeshSceneNode::render()
 {
@@ -232,7 +229,7 @@ void CMeshSceneNode::render()
 
 			for (u32 g=0; g<Mesh->getMeshBufferCount(); ++g)
 			{
-				driver->drawMeshBuffer( Mesh->getMeshBuffer(g) );
+				driver->drawMeshBuffer(Mesh->getMeshBuffer(g));
 			}
 		}
 	}
@@ -255,8 +252,8 @@ video::SMaterial& CMeshSceneNode::getMaterial(u32 i)
 {
 	if (Mesh && ReadOnlyMaterials && i<Mesh->getMeshBufferCount())
 	{
-		tmpReadOnlyMaterial = Mesh->getMeshBuffer(i)->getMaterial();
-		return tmpReadOnlyMaterial;
+		ReadOnlyMaterial = Mesh->getMeshBuffer(i)->getMaterial();
+		return ReadOnlyMaterial;
 	}
 
 	if (i >= Materials.size())
@@ -266,7 +263,6 @@ video::SMaterial& CMeshSceneNode::getMaterial(u32 i)
 }
 
 
-
 //! returns amount of materials used by this scene node.
 u32 CMeshSceneNode::getMaterialCount() const
 {
@@ -277,19 +273,18 @@ u32 CMeshSceneNode::getMaterialCount() const
 }
 
 
-
 //! Sets a new mesh
 void CMeshSceneNode::setMesh(IMesh* mesh)
 {
-	if (!mesh)
-		return; // won't set null mesh
+	if (mesh)
+	{
+		mesh->grab();
+		if (Mesh)
+			Mesh->drop();
 
-    mesh->grab();
-	if (Mesh)
-		Mesh->drop();
-
-	Mesh = mesh;
-	copyMaterials();
+		Mesh = mesh;
+		copyMaterials();
+	}
 }
 
 
@@ -322,6 +317,7 @@ void CMeshSceneNode::serializeAttributes(io::IAttributes* out, io::SAttributeRea
 	out->addBool("ReadOnlyMaterials", ReadOnlyMaterials);
 }
 
+
 //! Reads attributes of the scene node.
 void CMeshSceneNode::deserializeAttributes(io::IAttributes* in, io::SAttributeReadWriteOptions* options)
 {
@@ -341,9 +337,38 @@ void CMeshSceneNode::deserializeAttributes(io::IAttributes* in, io::SAttributeRe
 			setMesh(newMesh);
 	}
 
+	// optional attribute to assign the hint to the whole mesh
+	if (in->existsAttribute("HardwareMappingHint") &&
+		in->existsAttribute("HardwareMappingBufferType"))
+	{
+		scene::E_HARDWARE_MAPPING mapping = scene::EHM_NEVER;
+		scene::E_BUFFER_TYPE bufferType = scene::EBT_NONE;
+
+		core::stringc smapping = in->getAttributeAsString("HardwareMappingHint");
+		if (smapping.equals_ignore_case("static"))
+			mapping = scene::EHM_STATIC;
+		else if (smapping.equals_ignore_case("dynamic"))
+			mapping = scene::EHM_DYNAMIC;
+		else if (smapping.equals_ignore_case("stream"))
+			mapping = scene::EHM_STREAM;
+
+		core::stringc sbufferType = in->getAttributeAsString("HardwareMappingBufferType");
+		if (sbufferType.equals_ignore_case("vertex"))
+			bufferType = scene::EBT_VERTEX;
+		else if (sbufferType.equals_ignore_case("index"))
+			bufferType = scene::EBT_INDEX;
+		else if (sbufferType.equals_ignore_case("vertexindex"))
+			bufferType = scene::EBT_VERTEX_AND_INDEX;
+
+		IMesh* mesh = getMesh();
+		if (mesh)
+			mesh->setHardwareMappingHint(mapping, bufferType);
+	}
+
 	IMeshSceneNode::deserializeAttributes(in, options);
 }
 
+
 //! Sets if the scene node should not copy the materials of the mesh but use them in a read only style.
 /* In this way it is possible to change the materials a mesh causing all mesh scene nodes
 referencing this mesh to change too. */
@@ -352,6 +377,7 @@ void CMeshSceneNode::setReadOnlyMaterials(bool readonly)
 	ReadOnlyMaterials = readonly;
 }
 
+
 //! Returns if the scene node should not copy the materials of the mesh but use them in a read only style
 bool CMeshSceneNode::isReadOnlyMaterials() const
 {
@@ -362,8 +388,10 @@ bool CMeshSceneNode::isReadOnlyMaterials() const
 //! Creates a clone of this scene node and its children.
 ISceneNode* CMeshSceneNode::clone(ISceneNode* newParent, ISceneManager* newManager)
 {
-	if (!newParent) newParent = Parent;
-	if (!newManager) newManager = SceneManager;
+	if (!newParent)
+		newParent = Parent;
+	if (!newManager)
+		newManager = SceneManager;
 
 	CMeshSceneNode* nb = new CMeshSceneNode(Mesh, newParent,
 		newManager, ID, RelativeTranslation, RelativeRotation, RelativeScale);
@@ -372,13 +400,12 @@ ISceneNode* CMeshSceneNode::clone(ISceneNode* newParent, ISceneManager* newManag
 	nb->ReadOnlyMaterials = ReadOnlyMaterials;
 	nb->Materials = Materials;
 
-	if ( newParent )
+	if (newParent)
 		nb->drop();
 	return nb;
 }
 
 
-
 } // end namespace scene
 } // end namespace irr
 
