@@ -1,4 +1,4 @@
-// Copyright (C) 2002-2009 Nikolaus Gebhardt
+// Copyright (C) 2002-2010 Nikolaus Gebhardt
 // This file is part of the "Irrlicht Engine".
 // For conditions of distribution and use, see copyright notice in irrlicht.h
 
@@ -486,17 +486,11 @@ void COBJMeshFileLoader::readMTL(const c8* fileName, const io::path& relPath)
 	if (FileSystem->existFile(realFile))
 		mtlReader = FileSystem->createAndOpenFile(realFile);
 	else if (FileSystem->existFile(relPath + realFile))
-	{
 		mtlReader = FileSystem->createAndOpenFile(relPath + realFile);
-	}
 	else if (FileSystem->existFile(FileSystem->getFileBasename(realFile)))
-	{
 		mtlReader = FileSystem->createAndOpenFile(FileSystem->getFileBasename(realFile));
-	}
 	else
-	{
 		mtlReader = FileSystem->createAndOpenFile(relPath + FileSystem->getFileBasename(realFile));
-	}
 	if (!mtlReader)	// fail to open and read file
 	{
 		os::Printer::log("Could not open material file", realFile, ELL_WARNING);
@@ -507,6 +501,7 @@ void COBJMeshFileLoader::readMTL(const c8* fileName, const io::path& relPath)
 	if (!filesize)
 	{
 		os::Printer::log("Skipping empty material file", realFile, ELL_WARNING);
+		mtlReader->drop();
 		return;
 	}
 
@@ -818,7 +813,7 @@ u32 COBJMeshFileLoader::copyWord(c8* outBuf, const c8* const inBuf, u32 outBufLe
 	for (u32 j=0; j<length; ++j)
 		outBuf[j] = inBuf[j];
 
-	outBuf[i] = 0;
+	outBuf[length] = 0;
 	return length;
 }
 
